@@ -28,6 +28,6 @@ NULL
 
 not_in <- function(x,y)!('%in%'(x,y))
 
-# Get rid of NOTEs
-globalVariables(c(".", "name", "data"))
+# Get rid of NOTES
+globalVariables(c(".", "name", "data", "long_str"))
 
